@@ -1,5 +1,9 @@
+import copy
+
 import pytest
 
+import numpy as np
+
 from stepmix.datasets import (
     data_bakk_response,
     data_bakk_covariate,
@@ -21,6 +25,12 @@ def data_covariate():
     return X, Z
 
 
+@pytest.fixture
+def data_nested():
+    X, Y, _ = data_bakk_response(n_samples=100, sep_level=0.9, random_state=42)
+    return np.hstack((X, Y))
+
+
 @pytest.fixture
 def kwargs():
     # Default estimator arguments
@@ -37,6 +47,27 @@ def kwargs():
     return kwargs
 
 
+@pytest.fixture
+def kwargs_nested():
+    descriptor = {
+        "model_1": {"model": "bernoulli", "n_columns": 6},
+        "model_2": {"model": "gaussian_unit", "n_columns": 1},
+    }
+
+    # Default estimator arguments
+    kwargs = dict(
+        n_components=3,
+        measurement=copy.deepcopy(descriptor),
+        structural=copy.deepcopy(descriptor),
+        random_state=42,
+        abs_tol=1e-5,
+        n_init=2,
+        max_iter=200,
+        verbose=1,
+    )
+    return kwargs
+
+
 @pytest.fixture
 def kwargs_covariate():
     # Default estimator arguments
